@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import absolute_import, unicode_literals
-import json
 import snappy
 import six
 from growingio_tracker.data_parser import JsonParser
@@ -18,8 +17,7 @@ class SnappyParser(JsonParser):
         for message in messages:
             batch.append(self.json(message))
         batch_json = '[{0}]'.format(','.join(batch))
-        raw_data = json.dumps(batch_json)
-        compress_data = snappy.compress(raw_data)
+        compress_data = snappy.compress(batch_json)
         if self._crypt_data:
             return self._xor_crypt(compress_data, stm)
         return compress_data
